@@ -54,7 +54,7 @@ def record(cls: Type[R]) -> Type[R]:
         cls: the class to transform into a record
 
     Returns:
-        A class which can act as a record of the particular schema
+        A class which can act as a record of the particular schema \
         set by the attributes.
 
     Example:
@@ -66,21 +66,26 @@ def record(cls: Type[R]) -> Type[R]:
             red: int
             green: int
             blue: int
+            alpha: int = 1
 
         indigo = Color(red=75, green=0, blue=130)
 
         print(indigo)
-        # prints {'red': 75, 'green': 0, 'blue': 130}
+        # prints {'red': 75, 'green': 0, 'blue': 130, 'alpha': 1}
         ```
     """
+    annotations = utils.get_cls_annotations(cls, eval_str=True)
+    defaults = utils.get_cls_defaults(cls, annotations=annotations)
+
     return dataclasses.dataclass(
         type(
             cls.__name__,
             (Record,),
             {
-                "__annotations__": cls.__annotations__,
-                "__slots__": tuple(cls.__annotations__.keys()),
-                "__dataclass_fields__": cls.__annotations__,
+                "__annotations__": annotations,
+                "__slots__": tuple(annotations.keys()),
+                "__dataclass_fields__": annotations,
+                "__defaults__": defaults,
             },
         ),
         init=False,
@@ -110,8 +115,12 @@ class Record(types.MLType):
         TypeError: the data passed is does not correspond to the expected annotations.
     """
 
+    __defaults__: Dict[str, Any] = {}
+
     def __init__(self, **kwargs: Any):
+        kwargs = {**self.__defaults__, **kwargs}
         self.__attrs = kwargs
+
         if not _is_valid(kwargs, self.__annotations__):
             raise TypeError(
                 f"expected key-word arguments of signature {self.__annotations__}, got {kwargs}"
